#[repr(transparent)]pub struct LabelWithWidgets {
inner: TypedObjectRef<LabelWithWidgets, <LabelWithWidgets as ObjectSubclass>::ParentType>,
phantom: PhantomData<()>,
}Expand description
A Label that can have multiple widgets placed inside the text.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<LabelWithWidgets, <LabelWithWidgets as ObjectSubclass>::ParentType>phantom: PhantomData<()>Implementations
Sourceimpl LabelWithWidgets
impl LabelWithWidgets
Sourcepub fn use_markup(&self) -> <PhantomData<bool> as Property>::Value
pub fn use_markup(&self) -> <PhantomData<bool> as Property>::Value
Whether the label includes Pango markup.
Sourcepub fn set_use_markup<'a>(
&self,
value: impl Borrow<<<PhantomData<bool> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_use_markup<'a>( &self, value: impl Borrow<<<PhantomData<bool> as Property>::Value as HasParamSpec>::SetValue>, )
Whether the label includes Pango markup.
Sourcepub fn ellipsize(&self) -> <Cell<bool> as Property>::Value
pub fn ellipsize(&self) -> <Cell<bool> as Property>::Value
Whether the label should be ellipsized.
Sourcepub fn set_ellipsize<'a>(
&self,
value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_ellipsize<'a>( &self, value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>, )
Whether the label should be ellipsized.
Sourcepub fn justify(&self) -> <PhantomData<Justification> as Property>::Value
pub fn justify(&self) -> <PhantomData<Justification> as Property>::Value
The alignment of the lines in the text of the label, relative to each other.
Sourcepub fn set_justify<'a>(
&self,
value: impl Borrow<<<PhantomData<Justification> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_justify<'a>( &self, value: impl Borrow<<<PhantomData<Justification> as Property>::Value as HasParamSpec>::SetValue>, )
The alignment of the lines in the text of the label, relative to each other.
Sourcepub fn connect_label_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_label_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the label property
Sourcepub fn connect_use_markup_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_use_markup_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the use-markup property
Sourcepub fn connect_ellipsize_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_ellipsize_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the ellipsize property
Sourcepub fn connect_justify_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_justify_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the justify property
Sourcepub fn notify_label(&self)
pub fn notify_label(&self)
Notify listeners of a change in the label property
Sourcepub fn notify_use_markup(&self)
pub fn notify_use_markup(&self)
Notify listeners of a change in the use-markup property
Sourcepub fn notify_ellipsize(&self)
pub fn notify_ellipsize(&self)
Notify listeners of a change in the ellipsize property
Sourcepub fn notify_justify(&self)
pub fn notify_justify(&self)
Notify listeners of a change in the justify property
Sourceimpl LabelWithWidgets
impl LabelWithWidgets
Sourcepub(crate) const PLACEHOLDER: &'static str = "<widget>"
pub(crate) const PLACEHOLDER: &'static str = "<widget>"
The placeholder used to mark the locations of widgets in the label.